<!-- virtualmachines disks -->
<script id="services.virtualmachines.subscriptions.id.disks.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Unique Id: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.unique_id"><samp>{{value_or_none unique_id}}</samp></span></div>
        <div class="list-group-item-text item-margin">Provisioning State: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.provisioning_state"><samp>{{value_or_none provisioning_state}}</samp></span></div>
        <div class="list-group-item-text item-margin">Disk State: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.disk_state"><samp>{{value_or_none disk_state}}</samp></span></div>
        <div class="list-group-item-text item-margin">Time Created: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.time_created"><samp>{{format_date time_created}}</samp></span></div>
        <div class="list-group-item-text item-margin">Location: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.location"><samp>{{value_or_none location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Zones: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.zones"><samp>{{value_or_none zones}}</samp></span></div>
        <div class="list-group-item-text item-margin">Encryption: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.encryption_enabled"><samp>{{convert_bool_to_enabled encryption_enabled}}</samp></span></div>
        <div class="list-group-item-text item-margin">OS Type: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.os_type"><samp>{{value_or_none os_type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Managed By: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.managed_by"><samp>{{value_or_none managed_by}}</samp></span></div>
        <div class="list-group-item-text item-margin">Hyper V Generation: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.hyper_vgeneration"><samp>{{value_or_none hyper_vgeneration}}</samp></span></div>
        <div class="list-group-item-text item-margin">Disk Size GB: <span id="virtualmachines.subscriptions.{{subscription}}.disks.{{@key}}.disk_size_gb"><samp>{{value_or_none disk_size_gb}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.virtualmachines.subscriptions.id.disks", $("#services\\.virtualmachines\\.subscriptions\\.id\\.disks\\.partial").html());
</script>

<!-- Single virtualmachines disk template -->
<script id="single_virtualmachines_disk-template" type="text/x-handlebars-template">
    {{> modal-template template='services.virtualmachines.subscriptions.id.disks'}}
</script>
<script>
    var single_virtualmachines_disk_template = Handlebars.compile($("#single_virtualmachines_disk-template").html());
</script>
